@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2005 Marius L. Jøhndal
+  Copyright (C) 2005, 2007 Marius L. Jøhndal
  
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -15,7 +15,7 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
-  $Id: urlget.h,v 1.2 2005/11/13 21:53:00 mariuslj Exp $
+  $Id: urlget.h,v 1.3 2007/02/15 17:48:30 mariuslj Exp $
   
 */
 
@@ -24,7 +24,8 @@
 
 int libcastget_urlget_file(const char *url, FILE *f);
 int libcastget_urlget_buffer(const char *url, void *user_data,
-                             size_t (*write_buffer)(void *buffer, size_t size, size_t nmemb, void *user_data));
+                             size_t (*write_buffer)(void *buffer, size_t size, size_t nmemb, void *user_data),
+                             long resume_from);
 
 #endif /* URLGET_H */
 
