@@ -15,7 +15,7 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
-  $Id: utils.c,v 1.6 2006/07/28 20:32:28 mariuslj Exp $
+  $Id: utils.c,v 1.6.2.1 2007/11/13 19:10:54 mariuslj Exp $
   
 */
 
@@ -73,9 +73,15 @@ int libcastget_write_by_temporary_file(const gchar *filename,
   retval = writer(f, user_data);
     
   fclose(f);
-  close(fd);
-  
-  if (filename) {
+
+  if (errno == ENOSPC) {
+    fprintf(stderr, "No space left on device.\n");
+    unlink(tmp_filename_used);
+    g_free(tmp_filename_used);
+    return -1;
+  }
+
+  if (retval == 0 && filename) {
     if (g_rename(tmp_filename_used, filename) < 0) {
       fprintf(stderr, "Error renaming temporary file %s to %s: %s.\n",
               tmp_filename_used, filename, strerror(errno));
